@@ -56,7 +56,7 @@ from lfmaptools.utilities import (_nice_round,
                                   csv_num_cols,
                                   _decompress_gz)
 from lfmaptools.netcdf_utils import nc2np, nc_max, nc_min, nc_min_max
-from lfmaptools.geotools import LatLon_TM_polygonize, LatLon_TM
+from lfmaptools.geotools import EastingNorthing_TM, LatLon_TM_polygonize, LatLon_TM
 from lfmaptools.epsg_defs import webmerc, wgs84
 from lfmaptools.mapping import add_stamen_basemap
 from lfmaptools.interptools import interp_weights, interpolate
@@ -1364,28 +1364,17 @@ class LaharFlowData(object):
             var = [var]
 
         if filename is not None:
-            data = self.raster(filename, var=var, full_domain=full_domain, nodata=np.nan, masked=True, crs=None)
+            data = self._get_data(filename)
+
+        POI_xy = np.array(EastingNorthing_TM(self.clatlong, (lat, lon)))*1e3
+
+        indx = np.sqrt((data['x_distance']-POI_xy[0])**2+(data['y_distance']-POI_xy[1])**2)<buffer
         
-        data_utm = data.rio.reproject(self.utmCode)
-
-        df = pd.DataFrame({'Name':name, 'Longitude':[lon], 'Latitude':[lat]})
-        gdf = gpd.GeoDataFrame(df, geometry=gpd.points_from_xy(df.Longitude, df.Latitude), crs=wgs84)
-
-        gdf = gdf.to_crs(self.utmCode)
-        gdf['geometry'] = gdf.geometry.buffer(buffer)
-
-        (l, b, r, t) = data_utm.rio.bounds()
-        bbox = gpd.GeoDataFrame(geometry=[box(l,b,r,t)], crs=self.utmCode)
-
-        if not gdf.within(bbox)[0]:
-            return nodata
-
-        clip_poly = gdf.intersection(bbox)
-
-        if fill_value is not None:
-            data_utm = data_utm.fillna(fill_value)
-
-        data_clipped = data_utm.rio.clip(clip_poly)
+        data_clipped = data[var][indx]
+        data_clipped['x_distance'] = data['x_distance'][indx]
+        data_clipped['y_distance'] = data['y_distance'][indx]
+        data_clipped['latitude'] = data['latitude'][indx]
+        data_clipped['longitude'] = data['longitude'][indx]
         
         return data_clipped
     
